@@ -1,4 +1,3 @@
-
 #' Latest R release with a Windows installer available for download
 #'
 #' [r_release()] works based on the SVN tags in the main R source code
@@ -6,16 +5,25 @@
 #' is available for download. `r_release_win` returns the latest
 #' version for which a Windows installer is available.
 #'
+#' @section Note:
+#' This function is superseded by [resolve()]:
+#' ```{r}
+#' r_release_win()
+#' ```
+#' ```{r}
+#' resolve("release", platform = "windows")
+#' ```
+#'
 #' @return A one row data frame, with columns \sQuote{version},
 #'   \sQuote{date}, \sQuote{URL} and \sQuote{nickname}.
 #'
 #' @family R downloads
 #' @export
-#' @importFrom curl new_handle handle_setopt
-#' @examples
+#' @examplesIf rversions:::is_online()
 #' r_release()
 #' r_release_win()
 
 r_release_win <- function() {
-  keep_head(r_win_download_url, "-win.exe")
+  df <- api_version_df1("r-release-win")
+  df
 }
